/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.netbeans.modules.welcome.ui;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.swing.Action;
import org.openide.cookies.InstanceCookie;
import org.openide.filesystems.FileObject;
import org.openide.filesystems.FileUtil;
import org.openide.loaders.DataFolder;
import org.openide.loaders.DataObject;

/**
 *
 * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
 */
public class ActionBuilder {
    
    public List<DataObject> getDataObjects(String actionPath) {
        List<DataObject> returnList = new ArrayList<>();
        FileObject root = FileUtil.getConfigFile(actionPath);
        if (null == root) {
            Logger.getLogger(GetStarted.class.getName()).log(Level.INFO,
                    "Start page content not found: " + "FileObject: {0}", actionPath); //NOI18N
            return null;
        }
        DataFolder folder = DataFolder.findFolder(root);
        if (null == folder) {
            Logger.getLogger(GetStarted.class.getName()).log(Level.INFO,
                    "Start page content not found: " + "DataFolder: {0}", actionPath); //NOI18N
            return null;
        }
        DataObject[] children = folder.getChildren();
        if (null == children) {
            Logger.getLogger(GetStarted.class.getName()).log(Level.INFO,
                    "Start page content not found: " + "DataObject: {0}", actionPath); //NOI18N
            return null;
        }
        for (DataObject dataObject : children) {
            if (dataObject.getPrimaryFile().isFolder()) {
                DataFolder subFolder = DataFolder.findFolder(dataObject.getPrimaryFile());
                DataObject[] subFolderChildren = subFolder.getChildren();
                returnList.addAll(Arrays.asList(subFolderChildren));                
            } else {
                returnList.add(dataObject);
            }
        }
        return returnList;
    }
    
    /**
     * Extract the action from the data object
     * @param dob
     * @return 
     */
    public Action extractAction(DataObject dob) {
        InstanceCookie.Of instCookie = dob.getLookup().lookup(InstanceCookie.Of.class);
        if (null != instCookie && instCookie.instanceOf(Action.class)) {
            try {
                Action res = (Action) instCookie.instanceCreate();
                if (null != res) {
                    res.putValue(Action.NAME, dob.getNodeDelegate().getDisplayName());
                    res.putValue(Action.SHORT_DESCRIPTION, dob.getNodeDelegate().getDisplayName());
                    res.putValue(Action.LONG_DESCRIPTION, dob.getNodeDelegate().getDisplayName());
                    res.putValue(Action.LARGE_ICON_KEY, null);
                    res.putValue(Action.SMALL_ICON, null);
                }
                return res;
            } catch (IOException | ClassNotFoundException e) {
                Logger.getLogger(GetStarted.class.getName()).log(Level.INFO, null, e);
            }
        }
        return null;
    }
}
